@@ -58,7 +58,7 @@ class MangaStreamBase(Provider):
                     if cover_element:
                         cover = models.Cover(self)
                         cover.url = cover_element.attrs['src']
-                        manga.cover = cover
+                        manga.current_cover = cover
 
                     type_element = update_element.select_one('span.type')
                     type_text = type_element.string if type_element else ''
@@ -111,12 +111,32 @@ class MangaStreamBase(Provider):
             if id_text:
                 manga.id = id_text.strip()
 
+        # Cover
+        thumb_element = soup.select_one(
+            'div.thumb[itemtype="https://schema.org/ImageObject"] > img[itemprop="image"]'
+        )
+
+        if thumb_element:
+            thumb_url = thumb_element.attrs.get('src')
+
+            if thumb_url:
+                cover = models.Cover(self)
+                cover.url = thumb_url.strip()
+                manga.current_cover = cover
+
         # Title
         title_element = soup.select_one('h1.entry-title')
 
         title_text = title_element.string if title_element else ''
         if title_text:
-            manga.title = title_text
+            trans = title_text.maketrans({
+                "‘": "'",
+                "’": "'",
+                "“": "'",
+                "”": "'",
+            })
+            manga.title = title_text.strip()\
+                .translate(trans)
         else:
             raise Exception('Could not get title for comic')
 
@@ -153,7 +173,7 @@ class MangaStreamBase(Provider):
                 for alt_name in alt_text.split(','):
                     alt_names.append(alt_name.strip())
 
-        manga.alt = alt_names
+        manga.alts = alt_names
 
         # Description
         description_element = soup.select_one(
@@ -168,18 +188,44 @@ class MangaStreamBase(Provider):
                 "“": "'",
                 "”": "'",
             })
-            manga.description = description_text.strip('\n')\
+            manga.description = description_text.strip()\
                 .translate(trans)
 
         for metadata_element in soup.select('div.infox div.fmed'):
 
-            # Author            
-            author_names = []
-            if metadata_element and \
-                    metadata_element.select_one('b').string.strip() == 'Author' and \
-                    metadata_element.select_one('span').string.strip() not in wrong_field_values:
+            if metadata_element:
+                field_name_element = metadata_element.select_one('b')
+                if field_name_element:
+                    if field_name_element.string:
+                        field_name = field_name_element.string
+                    else:
+                        field_name = field_name_element.text
 
-                author_names_text = metadata_element.select_one('span').text.strip()
+                    field_name = field_name.strip()
+                else:
+                    continue
+
+                field_value_element = metadata_element\
+                    .select_one('span')
+                if field_value_element:
+                    if field_value_element.string:
+                        field_value = field_value_element.string.strip()
+                    else:
+                        field_value = field_value_element.text.strip()
+
+                    field_value = field_value.strip()
+
+                    if field_value in wrong_field_values:
+                        continue
+                else:
+                    continue
+            else:
+                continue
+
+            # Author
+            if field_name == 'Author':
+                author_names = []
+                author_names_text = field_value
 
                 for name in author_names_text.split('/'):
                     if name:
@@ -187,15 +233,12 @@ class MangaStreamBase(Provider):
                         person.name = name.strip()
                         author_names.append(person)
 
-            manga.authors = author_names
+                manga.authors = author_names
 
             # Artist
-            artist_names = []
-            if metadata_element and \
-                    metadata_element.select_one('b').string.strip() == 'Artist' and \
-                    metadata_element.select_one('span').string.strip() not in wrong_field_values:
-
-                artist_names_text = metadata_element.select_one('span').text.strip()
+            if field_name == 'Artist':
+                artist_names = []
+                artist_names_text = field_value
 
                 for name in artist_names_text.split('/'):
                     if name:
@@ -203,24 +246,22 @@ class MangaStreamBase(Provider):
                         person.name = name.strip()
                         artist_names.append(person)
 
-            manga.artists = artist_names
+                manga.artists = artist_names
 
             # Posted On
-            if metadata_element and \
-                    metadata_element.select_one('b').string.strip() == 'Posted On' and \
-                    metadata_element.select_one('span').text.strip() not in wrong_field_values:
+            if field_name == 'Posted On':
 
-                posted_on_dt = metadata_element.attrs.get('datetime')
+                posted_on_dt = field_value_element\
+                    .select_one('time').attrs.get('datetime')
 
                 if posted_on_dt:
                     manga.created_at = datetime.fromisoformat(posted_on_dt)
 
             # Updated On
-            if metadata_element and \
-                    metadata_element.select_one('b').string.strip() == 'Updated On' and \
-                    metadata_element.select_one('span').text.strip() not in wrong_field_values:
+            if field_name == 'Updated On':
 
-                updated_on_dt = metadata_element.attrs.get('datetime')
+                updated_on_dt = field_value_element\
+                    .select_one('time').attrs.get('datetime')
 
                 if posted_on_dt:
                     manga.created_at = datetime.fromisoformat(updated_on_dt)
@@ -282,20 +323,23 @@ class MangaStreamBase(Provider):
             lis = breadcrumb_element.select('li[itemprop="itemListElement"]')
 
             title_element = lis[1]
-            title_text = title_element.select_one('span[itemprop="name"]').string if title_element else ''
-            
+            title_text = title_element.select_one(
+                'span[itemprop="name"]').string if title_element else ''
+
             chapter_bc = lis[2]
-            chapter_name_text = chapter_bc.select_one('span[itemprop="name"]').string if chapter_bc else ''
+            chapter_name_text = chapter_bc.select_one(
+                'span[itemprop="name"]').string if chapter_bc else ''
 
             if title_text and chapter_name_text:
                 chapter_text = chapter_name_text\
-                        .strip().lstrip(title_text).strip()
-                
+                    .strip().replace(title_text, "", 1).strip()
                 chapter_number = re.findall('Chapter (\d+)', chapter_text)
                 if chapter_number:
                     chapter_number = chapter_number[0]
 
                     chapter.number = str(float(chapter_number))
+                else:
+                    raise Exception('Chapter number not found')
 
         pages = []
         pages_element = soup.select_one('div#readerarea')
@@ -327,19 +371,21 @@ class MangaStreamBase(Provider):
 
             if chapter_element:
 
-                chapter_url_element = chapter_element.select_one('div.eph-num > a')
+                chapter_url_element = chapter_element.select_one(
+                    'div.eph-num > a')
                 if chapter_url_element:
                     chapter.url = chapter_url_element.attrs['href']
 
                 chapter_number = chapter_element.attrs['data-num']
                 if chapter_number:
                     chapter.number = str(float(chapter_number))
-                
+
                 date_element = chapter_element.select_one('span.chapterdate')
                 date_text = date_element.string if date_element else ''
                 if date_text:
-                    chapter.created_at = datetime.strptime(date_text, '%B %d, %Y')
-            
+                    chapter.created_at = datetime.strptime(
+                        date_text, '%B %d, %Y')
+
             chapter_list.append(chapter)
 
         return chapter_list
